==> qtjambi-debuginfo-windows-x64-6.5.4.jar: sources/QtJambiGui/QDropEvent_shell.h <==
#ifndef QDROPEVENT_SHELL_H
#define QDROPEVENT_SHELL_H

#include <QtCore/QtGlobal>
#include <QtCore/qcompilerdetection.h>

QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wdeprecated-declarations")

#include <QtGui/qevent.h>
#include <QtJambi/QtJambiAPI>
#include <QtCore/QVariant>
#include <QtCore/qcoreevent.h>
#include <QtCore/qmimedata.h>
#include <QtCore/qnamespace.h>
#include <QtCore/qobject.h>
#include <QtCore/qpoint.h>
#include <QtJambi/RegistryAPI>


class QDropEvent_shell : public QDropEvent, public QtJambiShellInterface
{
public:
    QDropEvent_shell(const QDropEvent& arg__1);
    QDropEvent_shell(const QPointF& pos0, Qt::DropActions actions1, const QMimeData* data2, Qt::MouseButtons buttons3, Qt::KeyboardModifiers modifiers4, QEvent::Type type5 = QEvent::Drop);
    ~QDropEvent_shell() override;

    QDropEvent* clone() const override;
    void setAccepted(bool accepted0) override;
    static void operator delete(void * ptr) noexcept;
private:
    QtJambiShell* __shell() const override final;
    jmethodID __shell_javaMethod(int pos) const;
};

struct QDropEvent_access : public QDropEvent
{
    void __qt_assign_cref_QDropEvent(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID other0);
    jobject __qt_clone(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId) const;
    void setPossibleActions_cref_Qt_DropActions(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jint possibleActions0);
    void setMimeData_const_QMimeData_ptr(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID mimeData0);
    void setProposedAction_cref_Qt_DropAction(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jint proposedAction0);
    void setKeyboardModifiers_cref_Qt_KeyboardModifiers(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jint keyboardModifiers0);
    void setMouseButtons_cref_Qt_MouseButtons(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jint mouseButtons0);
    void setPosition_cref_QPointF(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID position0);
};

#endif // QDROPEVENT_SHELL_H

==> qtjambi-debuginfo-windows-x64-6.6.3.jar: sources/QtJambiGui/QDropEvent_shell.h <==
#ifndef QDROPEVENT_SHELL_H
#define QDROPEVENT_SHELL_H

#include <QtCore/QtGlobal>
#include <QtCore/qcompilerdetection.h>

QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wdeprecated-declarations")

#include <QtGui/qevent.h>
#include <QtJambi/QtJambiAPI>
#include <QtCore/QVariant>
#include <QtCore/qcoreevent.h>
#include <QtCore/qmimedata.h>
#include <QtCore/qnamespace.h>
#include <QtCore/qobject.h>
#include <QtCore/qpoint.h>
#include <QtJambi/RegistryAPI>


class QDropEvent_shell : public QDropEvent, public QtJambiShellInterface
{
public:
    QDropEvent_shell(const QDropEvent& arg__1);
    QDropEvent_shell(const QPointF& pos0, Qt::DropActions actions1, const QMimeData* data2, Qt::MouseButtons buttons3, Qt::KeyboardModifiers modifiers4, QEvent::Type type5 = QEvent::Drop);
    ~QDropEvent_shell() override;

    QDropEvent* clone() const override;
    void setAccepted(bool accepted0) override;
    static void operator delete(void * ptr) noexcept;
private:
    QtJambiShell* __shell() const override final;
    jmethodID __shell_javaMethod(int pos) const;
};

struct QDropEvent_access : public QDropEvent
{
    void __qt_assign_cref_QDropEvent(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID other0);
    jobject __qt_clone_constfct(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId) const;
    void setPossibleActions_cref_Qt_DropActions(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jint possibleActions0);
    void setMimeData_const_QMimeData_ptr(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID mimeData0);
    void setProposedAction_cref_Qt_DropAction(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jint proposedAction0);
    void setKeyboardModifiers_cref_Qt_KeyboardModifiers(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jint keyboardModifiers0);
    void setMouseButtons_cref_Qt_MouseButtons(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jint mouseButtons0);
    void setPosition_cref_QPointF(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID position0);
};

#endif // QDROPEVENT_SHELL_H
